/*
FESTIVAL PROGRAM PLUG-IN
Special for site http://www.jazzglobus.com/
Created by Victor Waldberg, IWD 2013
Ver.1.0.4 (Release: 07.11.2013)

JQUERY SCRIPT
*/

(function ($) {
    // Load plug-in
    $.fn.festival = function (_startIdx) {

        // Settings: default and parameters
        var setting = $.extend({
            startIdx: _startIdx || 0,       // Start slide index
            aWidth: 600,                    // Active slide width, pixels
            moveSpeed: 500,                 // Slide moving duration speed, msec.
            upTop: -315,                    // Top box offset, pixels
            boxTop: 50,                     // Top box default coordinate, pixels
            boxMargin: 20,                  // Boxes vertical margins, pixels
            loadTimeOut: 250                // Loading time out, msec.
        });

        // Plug-in attached object
        var _main = this;
        // Detect incompatible (early IE9) versions
        if (!$.support.leadingWhitespace) {
            $(_main).hide();
        }

        // Inner tags array
        var _slides = $('li', _main);
        // Set default active item
        var length = _slides.size() || 0;
        var _slide = (setting.startIdx >= 0 && setting.startIdx < length) ? _slides.get(setting.startIdx) : _slides.first();

        // Get accordion placeholder width
        var w = parseInt(_main.width());
        // Calc floating slides width
        var fWidth = length > 1 ? parseInt((w - setting.aWidth) / (length - 1)) : 0;

        // Set summary slides width 
        var sumWidth = 0;
        // Set default width style
        _slides.each(function (index) {
            // Set floated slides
            $(this).attr('style', 'width: ' + fWidth + 'px; overflow: hidden;');
            $(this).css('top', setting.boxTop + 'px');
            // Calculate summary slides width
            sumWidth += index == setting.startIdx ? setting.aWidth : fWidth;
        });

        // Calc last slide width
        var fWLast = (w - sumWidth) > 0 ? fWidth + (w - sumWidth) : fWidth
        // Correct last slide width
        _slides.last().width(fWLast);

        // Set selected index slide style
        $(_slide).find('span.bookmark').addClass('start');
        // Set last item background to parent control
        var backImage = _slides.last().find('img').attr('src');
        $(_main).css('background', 'url("' + backImage + '") no-repeat top right');

        // Set active item
        $(_slide).removeAttr('style');
        // Start-up active slide loading
        setTimeout(function () { upItems($(_slide)) }, setting.loadTimeOut);

        // On mouse over event
        $(_slides).hover(function () {
            // If active slide is last
            var collWidth = ($(_slide).attr('id') == _slides.last().attr('id')) ? fWLast : fWidth;
            // Collapse active
            $(_slide).animate({ width: collWidth + 'px' }, { duration: setting.moveSpeed, queue: false });
            // Expand current slide
            $(this).animate({ width: setting.aWidth + 'px' }, { duration: setting.moveSpeed, queue: false });

            // If active slide was changed
            if ($(_slide).attr('id') != $(this).attr('id')) {
                // Hide old active slide inner item
                $(_slide).find('a.box').animate({ opacity: 'hide' }, setting.moveSpeed, function () {
                    $(this).removeClass('ready').css('top', setting.boxTop + 'px');
                });
                // Show current slide instead
                upItems($(this));
            }

            // Set current slide as active 
            _slide = this;
        });

        // Show after loading
        $(_main).css('visibility', 'visible');

        // On click event (TEMPORARY FOR DEVELOPMENT)
        var _boxes = $('a.box', _slides);
        $(_boxes).click(function () {
            alert($(this).find('strong').text());
        });

        // Up boxes at the same time
        function upItems(_e) {
            // Show inner box for active slide
            _e.find('a.box').each(function (index) {
                var t = setting.upTop + ($(this).height() + setting.boxMargin) * index;
                $(this).animate({ opacity: 'show', top: t + 'px' }, setting.moveSpeed, function () {
                    $(this).addClass('ready');
                });
            });
        }
    };
}(jQuery));
